package javax.swing.event;

import java.awt.event.InputEvent;
import javax.swing.text.Element;
import java.net.URL;
import java.util.EventObject;

public class HyperlinkEvent extends EventObject
{
    private HyperlinkEvent.EventType type;
    private URL u;
    private String desc;
    private Element sourceElement;
    private InputEvent inputEvent;
    
    public HyperlinkEvent(Object o, HyperlinkEvent.EventType eventType, URL url) {
        this(o, eventType, url, null);
    }
    
    public HyperlinkEvent(Object o, HyperlinkEvent.EventType eventType, URL url, String s) {
        this(o, eventType, url, s, null);
    }
    
    public HyperlinkEvent(Object source, HyperlinkEvent.EventType type, URL u, String desc, Element sourceElement) {
        super(source);
        this.type = type;
        this.u = u;
        this.desc = desc;
        this.sourceElement = sourceElement;
    }
    
    public HyperlinkEvent(Object source, HyperlinkEvent.EventType type, URL u, String desc, Element sourceElement, InputEvent inputEvent) {
        super(source);
        this.type = type;
        this.u = u;
        this.desc = desc;
        this.sourceElement = sourceElement;
        this.inputEvent = inputEvent;
    }
    
    public HyperlinkEvent.EventType getEventType() {
        return this.type;
    }
    
    public String getDescription() {
        return this.desc;
    }
    
    public URL getURL() {
        return this.u;
    }
    
    public Element getSourceElement() {
        return this.sourceElement;
    }
    
    public InputEvent getInputEvent() {
        return this.inputEvent;
    }
    
    public static final class EventType
    {
        public static final HyperlinkEvent.EventType ENTERED;
        public static final HyperlinkEvent.EventType EXITED;
        public static final HyperlinkEvent.EventType ACTIVATED;
        private String typeString;
        
        private EventType(String typeString) {
            this.typeString = typeString;
        }
        
        @Override
        public String toString() {
            return this.typeString;
        }
        
        static {
            ENTERED = new HyperlinkEvent.EventType("ENTERED");
            EXITED = new HyperlinkEvent.EventType("EXITED");
            ACTIVATED = new HyperlinkEvent.EventType("ACTIVATED");
        }
    }
}
